emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 2d42bf7 3/3: ediff: use user-error rather than debu


From: Glenn Morris
Subject: [Emacs-diffs] master 2d42bf7 3/3: ediff: use user-error rather than debug-ignored-errors
Date: Mon, 17 Apr 2017 20:16:43 -0400 (EDT)

branch: master
commit 2d42bf7f5e57001a836b7b4e6303fac9d3f00a1d
Author: Glenn Morris <address@hidden>
Commit: Glenn Morris <address@hidden>

    ediff: use user-error rather than debug-ignored-errors
    
    * lisp/vc/ediff-diff.el (ediff-prepare-error-list):
    * lisp/vc/ediff-help.el (ediff-help-for-quick-help):
    * lisp/vc/ediff-init.el (ediff-barf-if-not-control-buffer)
    (ediff-check-version):
    * lisp/vc/ediff-merg.el (ediff-shrink-window-C):
    * lisp/vc/ediff-mult.el (ediff-draw-dir-diffs, ediff-show-dir-diffs)
    (ediff-append-custom-diff, ediff-meta-show-patch)
    (ediff-filegroup-action, ediff-show-meta-buffer, ediff-show-registry)
    (ediff-get-meta-info, ediff-patch-file-form-meta):
    * lisp/vc/ediff-ptch.el (ediff-patch-file-internal):
    * lisp/vc/ediff-util.el (ediff-toggle-autorefine)
    (ediff--check-ancestor-exists, ediff-toggle-read-only)
    (ediff-toggle-wide-display, ediff-toggle-multiframe)
    (ediff-toggle-use-toolbar, ediff-toggle-show-clashes-only)
    (ediff-next-difference, ediff-previous-difference)
    (ediff-pop-diff, ediff-read-file-name, ediff-verify-file-buffer)
    (ediff-save-buffer):
    * lisp/vc/ediff-wind.el (ediff-make-wide-display):
    * lisp/vc/ediff.el (ediff-find-file, ediff-buffers-internal)
    (ediff-directories-internal, ediff-directory-revisions-internal)
    (ediff-regions-wordwise, ediff-regions-linewise)
    (ediff-load-version-control): Use user-error.
    (debug-ignored-errors): No longer modify.
---
 lisp/vc/ediff-diff.el |  2 +-
 lisp/vc/ediff-help.el |  4 +--
 lisp/vc/ediff-init.el |  6 ++--
 lisp/vc/ediff-merg.el |  2 +-
 lisp/vc/ediff-mult.el | 26 ++++++++--------
 lisp/vc/ediff-ptch.el |  2 +-
 lisp/vc/ediff-util.el | 30 +++++++++---------
 lisp/vc/ediff-wind.el |  2 +-
 lisp/vc/ediff.el      | 84 +++++++++++----------------------------------------
 9 files changed, 54 insertions(+), 104 deletions(-)

diff --git a/lisp/vc/ediff-diff.el b/lisp/vc/ediff-diff.el
index ded82c4..b957bdc 100644
--- a/lisp/vc/ediff-diff.el
+++ b/lisp/vc/ediff-diff.el
@@ -340,7 +340,7 @@ one optional arguments, diff-number to refine.")
        (ediff-skip-unsuitable-frames)
        (switch-to-buffer error-buf)
        (ediff-kill-buffer-carefully ctl-buf)
-       (error "Errors in diff output.  Diff output is in %S" diff-buff))))
+       (user-error "Errors in diff output.  Diff output is in %S" diff-buff))))
 
 ;; BOUNDS specifies visibility bounds to use.
 ;; WORD-MODE tells whether we are in the word-mode or not.
diff --git a/lisp/vc/ediff-help.el b/lisp/vc/ediff-help.el
index 52a4825..339d3a5 100644
--- a/lisp/vc/ediff-help.el
+++ b/lisp/vc/ediff-help.el
@@ -190,7 +190,7 @@ the value of this variable and the variables 
`ediff-help-message-*' in
                             (overlays-at pos)))))
 
     (if (not (stringp cmd))
-       (error "Hmm...  I don't see an Ediff command around here..."))
+       (user-error "Hmm...  I don't see an Ediff command around here..."))
 
     (ediff-documentation "Quick Help Commands")
 
@@ -236,7 +236,7 @@ the value of this variable and the variables 
`ediff-help-message-*' in
            ((string= cmd "s") (re-search-forward "^['`‘]s['’]"))
            ((string= cmd "+") (re-search-forward "^['`‘]\\+['’]"))
            ((string= cmd "=") (re-search-forward "^['`‘]=['’]"))
-           (t (error "Undocumented command! Type `G' in Ediff Control Panel to 
drop a note to the Ediff maintainer")))
+           (t (user-error "Undocumented command! Type `G' in Ediff Control 
Panel to drop a note to the Ediff maintainer")))
       ) ; let case-fold-search
     ))
 
diff --git a/lisp/vc/ediff-init.el b/lisp/vc/ediff-init.el
index e054268..59d97c3 100644
--- a/lisp/vc/ediff-init.el
+++ b/lisp/vc/ediff-init.el
@@ -385,8 +385,8 @@ It needs to be killed when we quit the session.")
 
 (defsubst ediff-barf-if-not-control-buffer (&optional meta-buf-p)
   (or (ediff-in-control-buffer-p meta-buf-p)
-      (error "%S: This command runs in Ediff Control Buffer only!"
-            this-command)))
+      (user-error "%S: This command runs in Ediff Control Buffer only!"
+                 this-command)))
 
 (defgroup ediff-highlighting nil
   "Highlighting of difference regions in Ediff."
@@ -758,7 +758,7 @@ TYPE-OF-EMACS is either `emacs' or `xemacs'."
                       (funcall op emacs-minor-version minor)
                     t)))
             (t
-             (error "%S: Invalid op in ediff-check-version" op)))))
+             (user-error "%S: Invalid op in ediff-check-version" op)))))
 
 (defun ediff-color-display-p ()
   (condition-case nil
diff --git a/lisp/vc/ediff-merg.el b/lisp/vc/ediff-merg.el
index d7fa74f..d91d044 100644
--- a/lisp/vc/ediff-merg.el
+++ b/lisp/vc/ediff-merg.el
@@ -281,7 +281,7 @@ With a prefix argument, returns window C to its normal size.
 Used only for merging jobs."
   (interactive "P")
   (if (not ediff-merge-job)
-      (error "ediff-shrink-window-C can be used only for merging jobs"))
+      (user-error "ediff-shrink-window-C can be used only for merging jobs"))
   (cond ((eq arg '-) (setq arg -1))
        ((not (numberp arg)) (setq arg nil)))
   (cond ((null arg)
diff --git a/lisp/vc/ediff-ptch.el b/lisp/vc/ediff-ptch.el
index 36aebf4..0340672 100644
--- a/lisp/vc/ediff-ptch.el
+++ b/lisp/vc/ediff-ptch.el
@@ -766,7 +766,7 @@ you can still examine the changes via M-x ediff-files"
                (select-window aux-wind)
                (goto-char (point-max))))
          (switch-to-buffer-other-window patch-diagnostics)
-         (error "Patch appears to have failed")))
+         (user-error "Patch appears to have failed")))
 
     ;; If black magic is involved, apply patch to a temp copy of the
     ;; file.  Otherwise, apply patch to the orig copy.  If patch is applied
diff --git a/lisp/vc/ediff-util.el b/lisp/vc/ediff-util.el
index aea5f76..bcf446a 100644
--- a/lisp/vc/ediff-util.el
+++ b/lisp/vc/ediff-util.el
@@ -939,7 +939,7 @@ On a dumb terminal, switches between ASCII highlighting and 
no highlighting."
   (interactive)
   (ediff-barf-if-not-control-buffer)
   (if ediff-word-mode
-      (error "No fine differences in this mode"))
+      (user-error "No fine differences in this mode"))
   (cond ((eq ediff-auto-refine 'nix)
         (setq ediff-auto-refine 'on)
         (ediff-make-fine-diffs ediff-current-difference 'noforce)
@@ -956,9 +956,9 @@ On a dumb terminal, switches between ASCII highlighting and 
no highlighting."
 (defun ediff--check-ancestor-exists ()
   (or (ediff-buffer-live-p ediff-ancestor-buffer)
       (if ediff-merge-with-ancestor-job
-         (error "Lost connection to ancestor buffer.  This shouldn't happen.  \
+         (user-error "Lost connection to ancestor buffer.  This shouldn't 
happen.  \
 Please report this bug to address@hidden")
-       (error "Not merging with ancestor"))))
+       (user-error "Not merging with ancestor"))))
 
 ;; Restore `ediff-show-ancestor' on exit.
 (defun ediff--restore-options-on-exit ()
@@ -1080,7 +1080,7 @@ of the current buffer."
              (save-window-excursion
                (select-window (ediff-get-visible-buffer-window buf))
                (command-execute toggle-ro-cmd)))
-         (error "Don't know how to toggle read-only in buffer %S" buf))
+         (user-error "Don't know how to toggle read-only in buffer %S" buf))
 
        ;; Check if we made the current buffer updatable, but its file is RO.
        ;; Signal a warning in this case.
@@ -1270,7 +1270,7 @@ This is especially useful when comparing buffers 
side-by-side."
   (interactive)
   (ediff-barf-if-not-control-buffer)
   (or (ediff-window-display-p)
-      (error "%sEmacs is not running as a window application"
+      (user-error "%sEmacs is not running as a window application"
             (if (featurep 'emacs) "" "X")))
   (ediff-recenter 'no-rehighlight) ; make sure buffs are displayed in windows
   (let ((ctl-buf ediff-control-buffer))
@@ -1300,7 +1300,7 @@ which see."
   (interactive)
   (let (window-setup-func)
     (or (ediff-window-display-p)
-       (error "%sEmacs is not running as a window application"
+       (user-error "%sEmacs is not running as a window application"
               (if (featurep 'emacs) "" "X")))
 
   (cond ((eq ediff-window-setup-function 'ediff-setup-windows-multiframe)
@@ -1346,7 +1346,7 @@ To change the default, set the variable 
`ediff-use-toolbar-p', which see."
   (if (featurep 'ediff-tbar)
       (progn
        (or (ediff-window-display-p)
-           (error "%sEmacs is not running as a window application"
+           (user-error "%sEmacs is not running as a window application"
                   (if (featurep 'emacs) "" "X")))
        (if (ediff-use-toolbar-p)
            (ediff-kill-bottom-toolbar))
@@ -1401,7 +1401,7 @@ To change the default, set the variable 
`ediff-use-toolbar-p', which see."
   (interactive)
   (ediff-barf-if-not-control-buffer)
   (if (not ediff-merge-with-ancestor-job)
-      (error "This command makes sense only when merging with an ancestor"))
+      (user-error "This command makes sense only when merging with an 
ancestor"))
   (setq ediff-show-clashes-only (not ediff-show-clashes-only))
   (if ediff-show-clashes-only
       (message "Focus on regions where both buffers differ from the ancestor")
@@ -1793,7 +1793,7 @@ With a prefix argument, go forward that many differences."
        (ediff-unselect-and-select-difference n)
        ) ; let
     (ediff-visible-region)
-    (error "At end of the difference list")))
+    (user-error "At end of the difference list")))
 
 (defun ediff-previous-difference (&optional arg)
   "Go to the previous difference.
@@ -1842,7 +1842,7 @@ With a prefix argument, go back that many differences."
        (ediff-unselect-and-select-difference n)
        ) ; let
     (ediff-visible-region)
-    (error "At beginning of the difference list")))
+    (user-error "At beginning of the difference list")))
 
 ;; The diff number is as perceived by the user (i.e., 1+ the internal
 ;; representation)
@@ -2161,7 +2161,7 @@ ARG is a prefix argument.  If nil, copy the current 
difference region."
     (if (cdr saved-rec)
        (setq saved-diff (cdr saved-rec))
       (if (> ediff-number-of-differences 0)
-         (error "Nothing saved for diff %d in buffer %S" (1+ n) buf-type)
+         (user-error "Nothing saved for diff %d in buffer %S" (1+ n) buf-type)
        (error ediff-NO-DIFFERENCES)))
 
     (setq reg-beg (ediff-get-diff-posn buf-type 'beg n ediff-control-buffer))
@@ -3200,7 +3200,7 @@ Hit \\[ediff-recenter] to reset the windows afterward."
        (setq f (expand-file-name
                 (file-name-nondirectory default-file) f)))
     (if (and no-dirs (file-directory-p f))
-       (error "File %s is a directory" f))
+       (user-error "File %s is a directory" f))
     f))
 
 ;; If PREFIX is given, then it is used as a prefix for the temp file
@@ -3307,7 +3307,7 @@ Hit \\[ediff-recenter] to reset the windows afterward."
                (error
                 (beep)
                 (message "Couldn't save %s" buffer-file-name)))
-           (error "Buffer is out of sync for file %s" buffer-file-name))
+           (user-error "Buffer is out of sync for file %s" buffer-file-name))
        ;; If buffer is not obsolete and is not modified, do nothing
        nil)
     ;; If buffer is obsolete, offer to revert
@@ -3320,7 +3320,7 @@ Hit \\[ediff-recenter] to reset the windows afterward."
          (if file-magic
              (erase-buffer))
          (revert-buffer t t))
-      (error "Buffer out of sync for file %s" buffer-file-name))))
+      (user-error "Buffer out of sync for file %s" buffer-file-name))))
 
 ;; if there is another buffer visiting the file of the merge buffer, offer to
 ;; save and delete the buffer; else bark
@@ -3375,7 +3375,7 @@ Without an argument, it saves customized diff argument, 
if available
                    ediff-custom-diff-buffer)
                   ((ediff-buffer-live-p ediff-diff-buffer)
                    ediff-diff-buffer)
-                  (t (error "Output from `diff' not found"))))
+                  (t (user-error "Output from `diff' not found"))))
            )
     (let ((window-min-height 2))
       (save-buffer))))
diff --git a/lisp/vc/ediff-wind.el b/lisp/vc/ediff-wind.el
index 9b3d53f..31dcf3b 100644
--- a/lisp/vc/ediff-wind.el
+++ b/lisp/vc/ediff-wind.el
@@ -1184,7 +1184,7 @@ The frame to be resized is kept in 
`ediff-wide-display-frame'.
 This function modifies only the left margin and the width of the display.
 It assumes that it is called from within the control buffer."
   (if (not (fboundp 'ediff-display-pixel-width))
-      (error "Can't determine display width"))
+      (user-error "Can't determine display width"))
   (let* ((frame-A (window-frame ediff-window-A))
         (frame-A-params (frame-parameters frame-A))
         (cw (ediff-frame-char-width frame-A))
diff --git a/lisp/vc/ediff.el b/lisp/vc/ediff.el
index 07c5cea..4751bb6 100644
--- a/lisp/vc/ediff.el
+++ b/lisp/vc/ediff.el
@@ -289,9 +289,9 @@ deleted."
         (file-magic (ediff-filename-magic-p file))
         (temp-file-name-prefix (file-name-nondirectory file)))
     (cond ((not (file-readable-p file))
-          (error "File `%s' does not exist or is not readable" file))
+          (user-error "File `%s' does not exist or is not readable" file))
          ((file-directory-p file)
-          (error "File `%s' is a directory" file)))
+          (user-error "File `%s' is a directory" file)))
 
     ;; some of the commands, below, require full file name
     (setq file (expand-file-name file))
@@ -481,13 +481,13 @@ If this file is a backup, `ediff' it with its original."
     (unwind-protect
        (progn
          (if (not (ediff-buffer-live-p buf-A))
-             (error "Buffer %S doesn't exist" buf-A))
+             (user-error "Buffer %S doesn't exist" buf-A))
          (if (not (ediff-buffer-live-p buf-B))
-             (error "Buffer %S doesn't exist" buf-B))
+             (user-error "Buffer %S doesn't exist" buf-B))
          (let ((ediff-job-name job-name))
            (if (and ediff-3way-comparison-job
                     (not buf-C-is-alive))
-               (error "Buffer %S doesn't exist" buf-C)))
+               (user-error "Buffer %S doesn't exist" buf-C)))
          (if (stringp buf-A-file-name)
              (setq buf-A-file-name (file-name-nondirectory buf-A-file-name)))
          (if (stringp buf-B-file-name)
@@ -784,13 +784,13 @@ names.  Only the files that are under revision control 
are taken into account."
       (setq dir3 (if (file-directory-p dir3) dir3 (file-name-directory dir3))))
 
   (cond ((string= dir1 dir2)
-        (error "Directories A and B are the same: %s" dir1))
+        (user-error "Directories A and B are the same: %s" dir1))
        ((and (eq jobname 'ediff-directories3)
              (string= dir1 dir3))
-        (error "Directories A and C are the same: %s" dir1))
+        (user-error "Directories A and C are the same: %s" dir1))
        ((and (eq jobname 'ediff-directories3)
              (string= dir2 dir3))
-        (error "Directories B and C are the same: %s" dir1)))
+        (user-error "Directories B and C are the same: %s" dir1)))
 
   (if merge-autostore-dir
       (or (stringp merge-autostore-dir)
@@ -816,15 +816,15 @@ names.  Only the files that are under revision control 
are taken into account."
        (cond ((and (stringp dir1) (string= merge-autostore-dir dir1))
               (or (y-or-n-p
                    "Directory for saving merged files = Directory A.  Sure? ")
-                  (error "Directory merge aborted")))
+                  (user-error "Directory merge aborted")))
              ((and (stringp dir2) (string= merge-autostore-dir dir2))
               (or (y-or-n-p
                    "Directory for saving merged files = Directory B.  Sure? ")
-                  (error "Directory merge aborted")))
+                  (user-error "Directory merge aborted")))
              ((and (stringp dir3) (string= merge-autostore-dir dir3))
               (or (y-or-n-p
                    "Directory for saving merged files = Ancestor Directory.  
Sure? ")
-                  (error "Directory merge aborted")))))
+                  (user-error "Directory merge aborted")))))
 
     (setq dir-diff-struct (ediff-intersect-directories
                           jobname
@@ -877,7 +877,7 @@ names.  Only the files that are under revision control are 
taken into account."
             (string= merge-autostore-dir dir1))
        (or (y-or-n-p
             "Directory for saving merged file = directory A.  Sure? ")
-           (error "Merge of directory revisions aborted")))
+           (user-error "Merge of directory revisions aborted")))
 
     (setq file-list
          (ediff-get-directory-files-under-revision
@@ -978,9 +978,9 @@ lines.  For large regions, use `ediff-regions-linewise'."
                          (ediff-other-buffer bf))
                        t))))
   (if (not (ediff-buffer-live-p buffer-A))
-      (error "Buffer %S doesn't exist" buffer-A))
+      (user-error "Buffer %S doesn't exist" buffer-A))
   (if (not (ediff-buffer-live-p buffer-B))
-      (error "Buffer %S doesn't exist" buffer-B))
+      (user-error "Buffer %S doesn't exist" buffer-B))
 
 
   (let ((buffer-A
@@ -1019,9 +1019,9 @@ lines.  For small regions, use `ediff-regions-wordwise'."
                          (ediff-other-buffer bf))
                        t))))
   (if (not (ediff-buffer-live-p buffer-A))
-      (error "Buffer %S doesn't exist" buffer-A))
+      (user-error "Buffer %S doesn't exist" buffer-A))
   (if (not (ediff-buffer-live-p buffer-B))
-      (error "Buffer %S doesn't exist" buffer-B))
+      (user-error "Buffer %S doesn't exist" buffer-B))
 
   (let ((buffer-A
          (ediff-clone-buffer-for-region-comparison buffer-A "-Region.A-"))
@@ -1467,7 +1467,7 @@ Uses `vc.el' or `rcs.el' depending on 
`ediff-version-control-package'."
            (message "") ; kill the message from `locate-library'
            (require ediff-version-control-package))
        (or silent
-           (error "Version control package %S.el not found.  Use vc.el instead"
+           (user-error "Version control package %S.el not found.  Use vc.el 
instead"
                   ediff-version-control-package)))))
 
 
@@ -1512,56 +1512,6 @@ With optional NODE, goes to that node."
                   (select-window ctl-window)
                   (set-window-buffer ctl-window ctl-buf)))))))
 
-
-(dolist (mess '("^Errors in diff output. Diff output is in "
-                "^Hmm... I don't see an Ediff command around here...$"
-                "^Undocumented command! Type `G' in Ediff Control Panel to 
drop a note to the Ediff maintainer$"
-                ": This command runs in Ediff Control Buffer only!$"
-                ": Invalid op in ediff-check-version$"
-                "^ediff-shrink-window-C can be used only for merging jobs$"
-                "^Lost difference info on these directories$"
-                "^This command is inapplicable in the present context$"
-                "^This session group has no parent$"
-                "^Can't hide active session, $"
-                "^Ediff: something wrong--no multiple diffs buffer$"
-                "^Can't make context diff for Session $"
-                "^The patch buffer wasn't found$"
-                "^Aborted$"
-                "^This Ediff session is not part of a session group$"
-                "^No active Ediff sessions or corrupted session registry$"
-                "^No session info in this line$"
-                "^`.*' is not an ordinary file$"
-                "^Patch appears to have failed$"
-                "^Recomputation of differences cancelled$"
-                "^No fine differences in this mode$"
-                "^Lost connection to ancestor buffer...sorry$"
-                "^Not merging with ancestor$"
-                "^Don't know how to toggle read-only in buffer "
-                "Emacs is not running as a window application$"
-                "^This command makes sense only when merging with an ancestor$"
-                "^At end of the difference list$"
-                "^At beginning of the difference list$"
-                "^Nothing saved for diff .* in buffer "
-                "^Buffer is out of sync for file "
-                "^Buffer out of sync for file "
-                "^Output from `diff' not found$"
-                "^You forgot to specify a region in buffer "
-                "^All right. Make up your mind and come back...$"
-                "^Current buffer is not visiting any file$"
-                "^Failed to retrieve revision: $"
-                "^Can't determine display width.$"
-                "^File `.*' does not exist or is not readable$"
-                "^File `.*' is a directory$"
-                "^Buffer .* doesn't exist$"
-                "^Directories . and . are the same: "
-                "^Directory merge aborted$"
-                "^Merge of directory revisions aborted$"
-                "^Buffer .* doesn't exist$"
-                "^There is no file to merge$"
-                "^Version control package .*.el not found. Use vc.el 
instead$"))
-  (add-to-list 'debug-ignored-errors mess))
-
-
 
 ;;; Command line interface
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/vc/ediff-mult.el b/lisp/vc/ediff-mult.el
index 41015f7..5bf94a5 100644
--- a/lisp/vc/ediff-mult.el
+++ b/lisp/vc/ediff-mult.el
@@ -1242,7 +1242,7 @@ behavior."
     (insert "\n")))
 
 (defun ediff-draw-dir-diffs (diff-list &optional buf-name)
-  (if (null diff-list) (error "Lost difference info on these directories"))
+  (if (null diff-list) (user-error "Lost difference info on these 
directories"))
   (setq buf-name
        (or buf-name
            (ediff-unique-buffer-name "*Ediff File Group Differences" "*")))
@@ -1360,7 +1360,7 @@ Useful commands:
   "Display differences among the directories involved in session group."
   (interactive)
   (if (ediff-one-filegroup-metajob)
-      (error "This command is inapplicable in the present context"))
+      (user-error "This command is inapplicable in the present context"))
   (or (ediff-buffer-live-p ediff-dir-diffs-buffer)
       (ediff-draw-dir-diffs ediff-dir-difference-list))
   (let ((buf ediff-dir-diffs-buffer))
@@ -1441,7 +1441,7 @@ Useful commands:
   (if (ediff-buffer-live-p ediff-parent-meta-buffer)
       (ediff-show-meta-buffer
        ediff-parent-meta-buffer ediff-meta-session-number)
-    (error "This session group has no parent")))
+    (user-error "This session group has no parent")))
 
 
 ;; argument is ignored
@@ -1592,7 +1592,7 @@ Useful commands:
     (cond (ignore)
          (unmark (ediff-set-session-status info nil))
 ;;;   (if (ediff-buffer-live-p session-buf)
 ;;;      (error "Can't hide active session, %s" (buffer-name session-buf)))
session-buf)))
          (t (ediff-set-session-status info ?H))))
   unmark)
 
@@ -1707,7 +1707,7 @@ Useful commands:
                (setq custom-diff-buf ediff-custom-diff-buffer)))))
 
     (or (ediff-buffer-live-p meta-diff-buff)
-       (error "Ediff: something wrong--killed multiple diff's buffer"))
+       (user-error "Ediff: something wrong--killed multiple diff's buffer"))
 
     (cond ((ediff-buffer-live-p custom-diff-buf)
           ;; for live session buffers we do them first because the user may
@@ -1740,7 +1740,7 @@ Useful commands:
             (insert "\n")))
          (t
           (ediff-kill-buffer-carefully meta-diff-buff)
-          (error "Session %d compares versions of file.  Such session must be 
active to enable multifile patch collection" sessionNum )))
+          (user-error "Session %d compares versions of file.  Such session 
must be active to enable multifile patch collection" sessionNum )))
     ))
 
 (defun ediff-collect-custom-diffs ()
@@ -1792,7 +1792,7 @@ all marked sessions must be active."
            (goto-char (point-min))
            (display-buffer ediff-tmp-buffer 'not-this-window)
            ))
-      (error "The patch buffer wasn't found"))))
+      (user-error "The patch buffer wasn't found"))))
 
 (declare-function ediff-directories-internal "ediff"
                  (dir1 dir2 dir3 regexp action jobname
@@ -1829,7 +1829,7 @@ all marked sessions must be active."
              (progn
                (ediff-set-session-status info nil)
                (ediff-update-meta-buffer meta-buf nil session-number))
-           (error "Aborted"))))
+           (user-error "Aborted"))))
 
     (ediff-with-current-buffer meta-buf
       (setq merge-autostore-dir
@@ -1927,7 +1927,7 @@ all marked sessions must be active."
                             ;; level; see below
                             (setcar
                              (quote ,info) ediff-control-buffer))))
-              (error "Aborted")))
+              (user-error "Aborted")))
            ((ediff-one-filegroup-metajob)      ; needs 1 file arg
             (funcall ediff-session-action-function
                      file1
@@ -2057,7 +2057,7 @@ all marked sessions must be active."
 
     (setq meta-buf (or meta-buf ediff-meta-buffer))
     (cond ((not (bufferp meta-buf))
-          (error "This Ediff session is not part of a session group"))
+          (user-error "This Ediff session is not part of a session group"))
          ((not (ediff-buffer-live-p meta-buf))
           (error
            "Can't find this session's group panel -- session itself is ok")))
@@ -2127,7 +2127,7 @@ all marked sessions must be active."
   (interactive)
   (ediff-update-registry)
   (if (not (ediff-buffer-live-p ediff-registry-buffer))
-      (error "No active Ediff sessions or corrupted session registry"))
+      (user-error "No active Ediff sessions or corrupted session registry"))
   (let (wind frame)
     ;; for some reason, point moves in ediff-registry-buffer, so we preserve it
     ;; explicitly
@@ -2299,7 +2299,7 @@ If this is a session registry buffer then just bury it."
     (or result
        (unless noerror
          (ediff-update-registry)
-         (error "No session info in this line")))))
+         (user-error "No session info in this line")))))
 
 
 (defun ediff-get-meta-overlay-at-pos (point)
@@ -2380,7 +2380,7 @@ If this is a session registry buffer then just bury it."
         session-buf beg-marker end-marker)
 
     (if (or (file-directory-p file) (string-match "/dev/null" file))
-       (error "`%s' is not an ordinary file" (file-name-as-directory file)))
+       (user-error "`%s' is not an ordinary file" (file-name-as-directory 
file)))
     (setq session-buf (ediff-get-session-buffer info)
          beg-marker (ediff-get-session-objB-name info)
@@ -1592,7 +1592,7 @@ Useful commands:
          (unmark (ediff-set-session-status info nil))
 ;;;   (if (ediff-buffer-live-p session-buf)
-;;;      (error "Can't hide active session, %s" (buffer-name session-buf)))
+;;;      (user-error "Can't hide active session, %s" (buffer-name 
session-buf)))
          (t (ediff-set-session-status info ?H))))
          end-marker (ediff-get-session-objC-name info))